from inrex import (
    match, 
    search, 
    split, 
    findall, 
    finditer, 
)
from sys import stdin

__all__ = [
    "match", 
    "search", 
    "split", 
    "findall", 
    "finditer", 
    "stdin", 
]
